@@ -10,10 +10,7 @@ use arc::Set;
 use common::{crypto::HashAlgorithm, headers::Header, verify::DomainKey};
 use dkim::{Atps, Canonicalization, DomainKeyReport};
 use dmarc::Dmarc;
-use hickory_resolver::{
-    proto::{error::ProtoError, op::ResponseCode},
-    TokioAsyncResolver,
-};
+use hickory_resolver::{proto::op::ResponseCode, TokioResolver};
 use mta_sts::{MtaSts, TlsRpt};
 use spf::{Macro, Spf};
 use std::{
@@ -38,10 +35,11 @@ pub mod spf;
 
 pub use flate2;
 pub use hickory_resolver;
+#[cfg(feature = "report")]
 pub use zip;
 
 #[derive(Clone)]
-pub struct MessageAuthenticator(pub TokioAsyncResolver);
+pub struct MessageAuthenticator(pub TokioResolver);
 
 pub struct Parameters<'x, P, TXT, MXX, IPV4, IPV6, PTR>
 where
@@ -110,7 +108,7 @@ pub struct AuthenticatedMessage<'x> {
     pub headers: Vec<(&'x [u8], &'x [u8])>,
     pub from: Vec<String>,
     pub raw_message: &'x [u8],
-    pub body_offset: usize,
+    pub body_offset: u32,
     pub body_hashes: Vec<(Canonicalization, HashAlgorithm, u64, Vec<u8>)>,
     pub dkim_headers: Vec<Header<'x, crate::Result<dkim::Signature>>>,
     pub ams_headers: Vec<Header<'x, crate::Result<arc::Signature>>>,
@@ -351,12 +349,6 @@ impl From<io::Error> for Error {
     }
 }
 
-impl From<ProtoError> for Error {
-    fn from(err: ProtoError) -> Self {
-        Error::DnsError(err.to_string())
-    }
-}
-
 #[cfg(feature = "rsa")]
 impl From<rsa::errors::Error> for Error {
     fn from(err: rsa::errors::Error) -> Self {
